This function computes a VAR model using glm.
VARglm(x, family, vars, adjacency, icfun = BIC, ...)A list containing:
The estimated graph
The information criterion
A data frame or matrix containing repeated measures
The family to be used. Defaults to gaussian if data is continuous or binomial if data is binary
Vector of variables to predict. If missing all variables are predicted.
Adjacency matrix. If missing full network is estimated
Information criterion function to be included in the output
Arguments used in the icfun
Sacha Epskamp <mail@sachaepskamp.com>