Learn R Programming

qgraph (version 1.10.1)

mutualInformation: Computes the mutual information between nodes

Description

Computes the mutual information from one node to all other nodes, or between sets of nodes.

Usage

mutualInformation(ggm, from, to = "all", covMat)

Value

A named numeric vector with the mutual information of each node in 'from'.

Arguments

ggm

Partial correlation network. Must be missing if 'covMat' is supplied (supplying both results in an error).

from

Integer or character (node label) vector corresponding to one set of nodes. Defaults to all nodes.

to

Integer or character (node label) vector corresponding to another set of nodes, or 'all' to compute the mutual information of each node to all other nodes.

covMat

Variance-covariance matrix. Can be missing if 'ggm' is supplied.

Author

Sacha Epskamp