Computes the mutual information from one node to all other nodes, or between sets of nodes.
mutualInformation(ggm, from, to = "all", covMat)A named numeric vector with the mutual information of each node in 'from'.
Partial correlation network. Must be missing if 'covMat' is supplied (supplying both results in an error).
Integer or character (node label) vector corresponding to one set of nodes. Defaults to all nodes.
Integer or character (node label) vector corresponding to another set of nodes, or 'all' to compute the mutual information of each node to all other nodes.
Variance-covariance matrix. Can be missing if 'ggm' is supplied.
Sacha Epskamp